========
Examples
========

Jupyter notebooks can be found in the **examples** directory.


Jupyter Notebooks
*****************

EnMAP AC
--------

.. include:: examples/sicor_ac_EnMAP/sicor_ac_EnMAP_adj.rst


Methane
-------

.. include:: examples/sicor_ch4/sicor_ch4_adj.rst


Sensor Independent Scene Detection
----------------------------------

.. include:: examples/sicor_scene_detection/sicor_scene_detection_adj.rst


Cloud Mask
----------

.. include:: examples/sicor_CloudMask/sicor_CloudMask_adj.rst


